This is a mock command designed to test mekara's natural language compilation and execution functionality.

When running this script, follow these steps:

1. Use `shuf` to generate a random number between 1 and 100
2. Have user guess the number. Do **NOT** guess a number on behalf of the user; you **MUST** ask the user for this number.
3. If the user guessed the right number, print out "You got it right!"; otherwise, print out "You got it wrong!"
4. If the user won, congratulate them on being such a prescient user. If they lost, give them a choice insult.
